@@ -1,16 +1,20 @@
-use serde::{Deserialize, Serialize};
 use std::fmt;
 use std::fmt::{Display, Formatter};
+use std::path::PathBuf;
+
+use serde::{Deserialize, Serialize};
 
 #[derive(Debug, Clone, Deserialize, Serialize)]
 pub struct Repository {
     pub name: String,
-    pub url: String,
+    #[serde(default)]
+    pub url: Option<String>,
+    #[serde(default)]
+    pub file: Option<PathBuf>,
 }
 
 impl Display for Repository {
     fn fmt(&self, f: &mut Formatter<'_>) -> fmt::Result {
-        // TODO
         write!(f, "{:?}", self)
     }
 }
